# Temperature Controls Erosion along Arctic Rivers
This Github repo contains code related to *Temperature Controls Erosion along Arctic Rivers*, a brief communication submitted to Nature Climate Change by Jordan Fields, Jack Kreisler, Evan Dethier, John Perrotti, and Carl Renshaw.

## Datasets

The primary dataset for this study was Landsat [5](https://developers.google.com/earth-engine/datasets/catalog/LANDSAT_LT05_C02_T1_L2), [7](https://developers.google.com/earth-engine/datasets/catalog/LANDSAT_LE07_C02_T1_L2), and [8](https://developers.google.com/earth-engine/datasets/catalog/LANDSAT_LC08_C02_T1_L2) surface reflectance images (Collection 2). Additional datasets include:

- [MERIT Hydro](https://developers.google.com/earth-engine/datasets/catalog/MERIT_Hydro_v1_0_1)
- [Arctic DEM](https://developers.google.com/earth-engine/datasets/catalog/UMN_PGC_ArcticDEM_V3_2m_mosaic)
- [SRTM](https://developers.google.com/earth-engine/datasets/catalog/CGIAR_SRTM90_V4)
- [HydroLAKES](https://gee-community-catalog.org/projects/hydrolakes/)
- ERA5-Land [daily](https://developers.google.com/earth-engine/datasets/catalog/ECMWF_ERA5_LAND_DAILY_AGGR) and [monthly](https://developers.google.com/earth-engine/datasets/catalog/ECMWF_ERA5_LAND_MONTHLY_AGGR)
- [CMIP6 GCM](https://developers.google.com/earth-engine/datasets/catalog/NASA_GDDP-CMIP6)

## Software

Datasets were accessed and analyzed through [Google Earth Engine](https://earthengine.google.com/). Results were exported from Earth Engine and further analyzed in R for trend analysis, statistics, and visualizations.

## Code

All code needed to reproduce the results is provided here. The purpose of and any results generated by each file are briefly described here.

### `buffer_generator`

Generates centroids along the Mackenzie River stream network inside the project study area. Exports `MERIT_Segment_Buffers` (which contains the centroids) and `MERIT_Unioned_Streams` (used in `thiessen_polys` to buffer the entire stream network). The buffers themselves are not used at all, only the centroids.

### `thiessen_polys`

Generates [Thiessen polygons](http://www.gitta.info/Accessibilit/en/html/UncProxAnaly_learningObject4.html) along the entire stream network within the study area. These polygons allow us to define discrete, non-overlapping study sites of generally similar size without any gaps between sites. Exports the collection of Thiessen polygons.

That collection has been manually reviewed to remove any problematic polygons, such as those that cover lakes, those with no water area, and those in areas where the stream is to narrow to consistently detect water (~100 m). The edited collection, used for all analysis, is `Good_Thiessens`.

### `cpixel_generator`

Generates a collection of yearly images that allow us to mask out and ignore water in near-channel lakes within `New_cpixel_AOI`. This region covers the study area north of ~67.5 degrees of latitude, where near-channel lakes are particularly numerous. Each year's image is created with a connected pixels analysis where any water pixels with fewer than 1024 connected neighbors are masked out and therefore not taken into account for any analysis. Exports `cpixel_Masks`, the collection of yearly masks.

Note -- review of yearly masks showed significant variation in the connectivity of near-channel lakes, which led to a noisy land gained/lost signal in the cpixel AOI. Thus, results from within the cpixel AOI are only analyzed in bulk analysis of all results (as noted in Online Methods).

### `slope_mask`

Creates a single image to mask out all areas with a slope greater than 22 within `High_Relief_Region` (an asset available in the script). Manual review of water detection accuracy showed that mountain shadows were sometimes erroneously detected as water, so creating and applying this mask allows for more accurate water detection. Exports `Mack_SlopeMask`.

### `Groundtruthing`

Used to manually delineate water for selected ground truth sites, with results shown Online Methods Fig. 3

### `MASTER_Temp_Calcs`

Uses ERA5 reanalysis data to calculate degree days and days above 0°C for each year for each Thiessen polygon. Also uses CMIP6 future climate projections to estimate future temperature changes across the project study area. Exports ***export info***

**Jordan to review/add detail**

### `MASTER_NDVI_Calcs`

Calculates mean per-pixel NDVI values for each year, then computes the mean NDVI value within each Thiessen polygon for each year. Exports ***export name***.

### `MASTER_meander_rates`

The main analysis for this study. Detects water in all Landsat 5, 7, and 8 images within the study area using a [Water Ratio Index (WRI)](https://doi.org/10.3390/hydrology10030070) algorithm supplemented by band-based masks, the connected pixel masks, and the slope mask. Determines yearly water occurrence across the entire study area using a two-year image window, where water pixels are those that are water in at least 20% of the images. Calculates area that changed from land to water (or vice versa) over rolling 5-year windows from 1990-2023. Counts total water area, land gained, and land lost within each Thiessen polygon for each rolling 5-year window, and exports the results as ***export names***.

### Assets

To reduce computational complexity and prevent time-out errors, some items (such as Thiessen polygons and connected pixel masks) are computed ahead of time and imported into Earth Engine scripts. These assets, along with the exported results tables, are listed in `list_of_assets` and also available in ***list folder with assets***.

### Batch Exports
Due to the vast number of images used and despite the ability to run computations on Earth Engine servers, we still encountered some memory limitations. To avoid these limitations and allow results to compute, in some cases we export the NDVI/temperature/meander results in batches. Each batch export comprises all years but only a subset of all Thiessen polygons. The for-loops and other commands used for batch exports are present in scripts (for transparency) but commented out (for clarity). Reproducing our results may or may not require batch exports, depending on code optimizations.
